@@ -22,8 +22,9 @@ from calculate.core.server.core_interfaces import MethodsInterface
 
 from calculate.desktop._cl_keys import getKey
 
-from calculate.lib.utils.files import (isMount, process,
-                                       getRunCommands, STDOUT, childMounts,
+from calculate.lib.utils.mount import isMount, childMounts
+from calculate.lib.utils.files import (process,
+                                       getRunCommands, STDOUT,
                                        getLoopFromPath,
                                        getMdRaidDevices, listDirectory,
                                        removeDir, rsync_files, RsyncOptions,
@@ -274,9 +275,12 @@ class Desktop(MethodsInterface):
             logoutCommand = "/usr/bin/kquitapp ksmserver"
         elif session == 'plasma':
             logoutCommand = "/usr/bin/pkill -f ksmserver"
-        elif session == 'gnome':
+        elif session in ('gnome', 'mate', 'cinnamon-session'):
             logoutCommand = "/usr/bin/qdbus org.gnome.SessionManager " \
                             "/org/gnome/SessionManager Logout 1"
+        elif session == 'lxqt':
+            logoutCommand = "/usr/bin/qdbus org.lxqt.session " \
+                            "/LXQtSession org.lxqt.session.logout"
         else:
             raise DesktopError(_("Unable to detect the X session"))
         if process("su", urLogin, "-c",
@@ -302,6 +306,7 @@ class Desktop(MethodsInterface):
                               getRunCommands(uid=uid)):
                     break
                 time.sleep(1)
+        time.sleep(1)
         
         if filter(lambda x: "xdm/xdm\x00--logout" in x,
                   getRunCommands()):
